function plot_goes_cube, times0, times1, _extra=_extra, $
   xsize=xsize, ysize=ysize, labels=labels, window_minutes=window_minutes, $
   evt_times=evt_times, evt_labels=evt_labels, title=title
;
;   Name: plot_goes_cube
;
;   Purpose: multiple events/times -> cube of plot_goes snapshots
;
;   Input Parameters:
;      times0 - center time or start time of ranges
;      times1 - stop times of ranges
;
;   Keyword Parameters:
;      xsize/ysize - size of output frames 
;      labels - optional vector of labels (1:1 for times0)
;      _EXTRA - unspecified keywords -> plot_goes via inheritance
;      window_minutes - expand each time or range by this 
;        (via time_window.pro;  if scalar = [-N,+N]
;                           2-elem vector = [-M,+N]
;-

case n_params() of 
   0: begin 
        box_message,'Must supply vector of times or time ranges...'
        return,-1 
      endcase
   1: times1=times0
   else:
endcase
 
if n_elements(xsize) eq 0 then xsize=512
if n_elements(ysize) eq 0 then ysize=xsize
if n_elements(window_minutes) eq 0 then window_minutes=20 ; 

st0=anytim(times0,/ecs)
st1=anytim(times1,/ecs)

nframes=n_elements(times0)
 
retval=bytarr(xsize,ysize,nframes)

wdef,zz,xsize,ysize,/zbuffer              ; use Z buffer
;linecolors

evtgrid=n_elements(evt_times) eq nframes  ; evt_grid requested?
if evtgrid and n_elements(evt_labels) eq 0 then $
   evt_labels=strarr(nframes)

if n_elements(title) eq nframes then titles=title else $
   title=strarr(nframes)

for i=0,nframes-1 do begin 
   time_window,[st0(i),st1(i)],minute=window_minutes,gt0,gt1
   plot_goes,gt0,gt1,_extra=_extra, title=title(i), $
      nodeftitle=(title(i)) ne ''
   if evtgrid then begin 
      evt_grid, evt_times(i),label=evt_labels(i), /arrow, $
         tickpos=.7, thick=2, color=100
   endif
   gplot=tvrd()
   retval(0,0,i)=gplot
endfor 

return,retval
end

