function pfss_fake_index,pii, pdd, _extra=_extra 
;
;+
;   Name: pfss_fake_index
;
;   Purpose: PFSS -> SSW interface utility
;
;   Input Parameters:
;      pii - any standard SSW time, index, or Map object
;
;   Output:
;      returns ssw style index with times/pointing derived from PFSS info
;
;   Keyword Parameters:
;      (may be via inheritance via caller..)
;      mag - magnification factor relative to 2.5" (mdi/pfss reference)
;      width - in solar radii ; default=2.5 per PFSS
;   
;   Calling Sequence:
;      index=pfss_fake_index(pii [,mag=mag ] , width=width
;
;   Method:
;      Set up a few PFSS assumptions per MAG&WIDTH and then call
;      ssw_fake_index
;
;
;   
 
if n_params() eq 0 then begin
   box_message,'Need an input time/index/or map)
   return,-1
endif

debug=keyword_set(debug)

case 1 of 
   valid_map(pii): time=anytim(gt_tagval(map,/TIME),/utc_int)
   else: time=anytim(pii,/utc_int)
endcase
defaults=0
case 1 of 
   data_chk(_extra,/struct):  begin
      mag=gt_tagval(_extra,/MAG,missing=1.0)
      width=gt_tagval(_extra,/WIDTH,missing=2.5)
   endcase
   else: begin ; all PFSS defaults
      width=2.5
      mag=1
      defaults=1
   endcase
endcase

if n_elements(pdd) gt 0 then begin 
   nx=data_chk(pdd,/nx)
   ny=data_chk(pdd,/ny)
   if defaults then begin 
      find_limb,pdd,x,y,rad
      mag=(rad/2.5)/192    ; PFSS normalize
      if debug then stop,'sun->mag'
   endif
endif 
cdelt1=2.5*(4./mag)
dimas=(pb0r(time,/arcsec))(2) ; solar radii "   
nx=width*192.*mag

if debug then stop
ssw_fake_index,time,ii,dd, cdelt1=cdelt1,xcen=0,ycen=0,/xcen_ycen, nx=nx

return,ii

end

