;  This script illustrates how one make a plot of ecliptic fieldlines
;  overplotted on coronal hole boundaries from the PFSS package, for use with
;  Sam's latest events page.

@pfss_data_block

;  set date
date='2003-04-05'  ;  or whatever date you need

;  get ephemeris info
lcent=(tim2carr(date))(0)  ;  carrington longitude in degrees
pb0rdata=pb0r(date)
bcent=pb0rdata(1)  ;  b angle in degrees

;  restore the desired savefile
pfss_restore,pfss_time2file(date)

;  get fieldline starting points (ecliptic)
necliptic=120  ;  number of ecliptic fieldlines
pfss_field_start_coord,1,necliptic,radstart=2.5

;  add to these fieldlines a set from the top
spacing=2.5  ;  fieldline spacing parameter
pfss_field_start_coord,5,spacing,radstart=2.5,/add
pfss_field_start_coord,5,spacing,radstart=rix(1),/add

;  trace the fieldlines
pfss_trace_field

;  get the coronal hole boundaries
pfss_get_chfootprint,openfield2,/quiet,/usecurrent  ;  for debugging
pfss_get_chfootprint,openfield,/quiet,/usecurrent,/close,spacing=spacing

;  rotate open field grid so that lcent is in the middle of the image (do this
;  because the contouring gives imperfections at the edges, so hide these on
;  the non-earth-facing side of the sun)
wh=where(lon gt lcent,nwh)
if nwh gt 0 then openoffset=wh(0)+nlon/2 else openoffset=nlon/2
openfield=shift(openfield,-openoffset)

;  smooth image slightly so that the contours are not as angular
openfield=filter_image(openfield,fwhm=1.5)  ;  in IDL astron library

;  plot the disk image
width=2.5  ;  image will be 2.5 solar diameters wide
magnification=2  ;  how big to make the resulting image
pfss_draw_field,imsc=200,outim=imdisk,lcent=lcent,bcent=bcent,width=width, $
  mag=magnification,/nolines,/quiet

;  get [x1,y1,x2,y2] of orthographic projection of disk
naxdisk=size(imdisk,/dim)
diam=float(naxdisk)/2.5  ;  2.5 is default width for pfss_draw_field
x1=round((naxdisk(0)-diam(0))/2)  &  x2=round(x1+diam(0))
y1=round((naxdisk(1)-diam(1))/2)  &  y2=round(y1+diam(1))
openpos=float([x1,y1,x2,y2])/[naxdisk,naxdisk]

;  draw coronal hole contours on the orthographic projection
olddname=!d.name  &  set_plot,'z'
device,set_resolution=naxdisk
scim,imdisk
map_set,/ortho,pos=openpos,/noer,/nobor,bcent,lcent-lon(openoffset)
contour,openfield,lon,lat,/overplot,/follow, $
  levels=[-0.03,0.03],c_labels=[0,0],c_colors=[249,0],pos=openpos,/norm
imdisk2=tvrd()

;  get fieldilne image
str=str(0:necliptic-1)
stth=stth(0:necliptic-1)
stph=stph(0:necliptic-1)
nstep=nstep(0:necliptic-1)
pfss_draw_field,imsc=200,outim=imlines,lcent=lcent,bcent=bcent,width=width, $
  mag=magnification,/noimage,/quiet

;  combine images
imfinal=imdisk2
wh=where(imlines gt 0,nwh)
if nwh gt 0 then imfinal(wh)=imlines(wh)

;  cleanup
set_plot,olddname

end
