function ssw_pfss2linecolors, pfssdata, lcolors=lcolors, noloadct=noloadct
;
;+
;   Name: ssw_pfss2linecolors
;
;   Purpose: map PFSS default colors -> linecolors.pro domain
;
;   Input Parameters:
;      pfssdata - output from ssw_index2pfss (Marc Derosa defaults)
;
;   Output Parameters:
;      function returns input data array with PFSS field line values
;      mapped to linecolors.pro values
;
;   Keyword Parameters:
;      lcolors - optional user desired mapping; default is 
;                [11,12,7,5] => [background, open-,    open+, closed]
;                                darkblue,   magenta,  green, yellow]
;
;      noloadct - do not load the color table (ie, dont run linecolors)
;
;   Calling Example:
;      IDL> ssw_index2pfss, sswindex,pfssindex,pfssdata [options]
;      IDL> lcpfss=ssw_pfss2linecolors(pfssdata) ; map pfss->linecolors
;      IDL> wdef,im=lcpfss & tv,lcpfss  ; show w/linecolors table
;
;   Side Effects:
;      low 16 values of current color table are "clobbered"; ie set
;      to linecolors.pro levels (override via /NOLOADCT)
;
;   History:
;      11-August-2004 - S.L.Freeland - pfss/ssw helper
;     
;- 
;
;
if n_elements(lcolors) ne 4 then lcolors=[11,12,7,5]
pfsscolors=[0,252,250,254]

if data_chk(pfssdata,/nimages) lt 1 then begin 
   box_message,'Need input data array from PFSS'
   return,-1
endif

pdd=pfssdata

for col=0,n_elements(pfsscolors)-1 do begin 
    ss=where(pfssdata eq pfsscolors(col),sscnt)
    if sscnt gt 0 then pdd(ss)=lcolors(col)
endfor

if not keyword_set(noloadct) then linecolors  ; load linecolors ct

return,pdd
end  

    


